@@ -516,8 +516,9 @@ tokens = vData.get (this.vibrationNumber % nData);
 ignore[i] = (!this.doGetVibration (++this.vibrationNumber) || tokens == null);
 if (ignore[i]) continue;
 this.applySymmetryAndSetTrajectory ();
-if (isFirst) modelAtomCount = this.asc.getLastAtomSetAtomCount ();
-this.cloneLastAtomSet (this.ac, null);
+if (isFirst) {
+modelAtomCount = this.asc.getLastAtomSetAtomCount ();
+}this.cloneLastAtomSet (this.ac, null);
 if (isFirst) {
 iAtom0 = this.asc.getLastAtomSetAtomIndex ();
 isFirst = false;
