@@ -92,7 +92,7 @@ if (ignore[i]) continue;
 this.applySymmetryAndSetTrajectory ();
 lastAtomCount = this.cloneLastAtomSet (ac, null);
 if (i == 0) iAtom0 = this.asc.getLastAtomSetAtomIndex ();
-this.asc.setAtomSetFrequency (null, null, String.valueOf (frequencies[i]), null);
+this.asc.setAtomSetFrequency (this.vibrationNumber, null, null, String.valueOf (frequencies[i]), null);
 this.asc.setAtomSetName (JU.DF.formatDecimal (frequencies[i], 2) + " cm-1");
 }
 this.rd ();
