@@ -216,6 +216,10 @@ s = this.getPropI ("list", index);
 if (s.length > 1) s += "cutoff = " + this.jvxlData.cutoff + "\n";
 s = "\n" + s;
 }return this.getMoInfo (-1) + s;
+}if (propertyName === "moLabel") {
+var labels = this.sg.params.moData.get ("nboLabels");
+if (this.$moNumber > 0 && labels != null && labels.length != 0) return labels[(this.$moNumber - 1) % labels.length];
+return "";
 }if (propertyName === "moNumber") return Integer.$valueOf (this.$moNumber);
 if (propertyName === "moLinearCombination") return this.$moLinearCombination;
 if (propertyName === "moSquareData") return this.moSquareData;
