@@ -1683,7 +1683,7 @@ return bs;
 }, "~N,~O,JU.BS");
 Clazz.defineMethod (c$, "getChainBits", 
 function (chainID) {
-var caseSensitive = this.vwr.getBoolean (603979823);
+var caseSensitive = this.vwr.getBoolean (603979822);
 if (chainID >= 0 && chainID < 300 && !caseSensitive) chainID = this.chainToUpper (chainID);
 var bs =  new JU.BS ();
 var bsDone = JU.BS.newN (this.ac);
@@ -1964,7 +1964,7 @@ return list;
 }, "~S");
 Clazz.defineMethod (c$, "scaleVectorsToMax", 
 function (max) {
-if (this.vibrations == null || max == 0) return;
+if (this.vibrations == null) return;
 var m = 0;
 var bsVib = JU.BS.newN (this.ac);
 for (var i = this.vibrations.length; --i >= 0; ) {
@@ -1973,15 +1973,18 @@ if (v != null && (v.modDim == -1 || v.modDim == -2)) {
 m = Math.max (m, v.length ());
 bsVib.set (i);
 }}
-if (m == 0 || m == max) return;
+if (m == max || m == 0) return;
 m = max / m;
 var ok = false;
 for (var i = bsVib.nextSetBit (0); i >= 0; i = bsVib.nextSetBit (i + 1)) {
 var v = this.getVibration (i, false);
 var mod = this.getModulation (i);
-if (mod != null) mod.scaleVibration (m);
- else v.scale (m);
-if (!ok) {
+if (mod == null) {
+if (m == 0) return;
+v.scale (m);
+} else {
+mod.scaleVibration (m);
+}if (!ok) {
 this.taintAtom (i, 12);
 ok = true;
 }}
