@@ -292,6 +292,8 @@ return JU.Measure.getPlaneThroughPoints (pt1, pt2, pt3,  new JU.V3 (),  new JU.V
 Clazz.defineMethod (c$, "getPointOrPlane", 
 function (index, integerOnly, allowFractional, doConvert, implicitFractional, minDim, maxDim) {
 var coord =  Clazz.newFloatArray (6, 0);
+var code555 =  Clazz.newIntArray (6, 0);
+var useCell555P4 = false;
 var n = 0;
 this.coordinatesAreFractional = implicitFractional;
 if (this.tokAt (index) == 8) {
@@ -321,6 +323,8 @@ break;
 case 2:
 case 1073742362:
 if (n == 6) this.invArg ();
+if (implicitFractional && this.theToken.intValue > 999999999) useCell555P4 = true;
+code555[n] = this.theToken.intValue;
 coord[n++] = this.theToken.intValue * multiplier;
 multiplier = 1;
 break;
@@ -352,7 +356,9 @@ this.invArg ();
 }
 if (n < minDim || n > maxDim) this.invArg ();
 if (n == 3) {
-var pt = JU.P3.new3 (coord[0], coord[1], coord[2]);
+if (useCell555P4) {
+return JU.P4.new4 (coord[0], coord[1], coord[2], (code555[0] % 1000) * 1000 + (code555[1] % 1000) + 1000000);
+}var pt = JU.P3.new3 (coord[0], coord[1], coord[2]);
 if (this.coordinatesAreFractional && doConvert) {
 this.fractionalPoint = JU.P3.newP (pt);
 if (!this.chk) this.vwr.toCartesian (pt, false);
