@@ -442,8 +442,9 @@ this.exitMeasurementMode ("escape");
 break;
 }
 var action = 16 | 256 | 8192 | this.moved.modifiers;
-if (!this.labelMode && !this.b.isUserAction (action)) this.checkMotionRotateZoom (action, this.current.x, 0, 0, false);
-if (this.vwr.getBoolean (603979889)) {
+if (!this.labelMode && !this.b.isUserAction (action)) {
+this.checkMotionRotateZoom (action, this.current.x, 0, 0, false);
+}if (this.vwr.getBoolean (603979889)) {
 switch (key) {
 case 38:
 case 40:
