@@ -7,8 +7,8 @@ case 1275069446:case 1275069447:case 1275068932:return this.evaluateString(d,a.i
 b,c,268435665==a.tok);case 1275068444:case 1275068425:return this.evaluateSort(d,b,c);case 1296041986:return this.evaluateSymop(d,b,268435665==a.tok);case 1275068445:return this.evaluateTensor(d,b);case 134217759:return this.evaluateWithin(d,b);case 134221856:return this.evaluateWrite(d,b)}return!1},"JS.ScriptMathProcessor,JS.T,~A,~N");l(c$,"evaluatePointGroup",function(d,a){var b=null,c=null,e=NaN,g=NaN,f;switch(a.length){case 4:g=a[3].asFloat();case 3:e=a[2].asFloat();case 2:switch(a[1].tok){case 8:c=
 JS.SV.ptValue(a[1]);break;case 10:f=JS.SV.getBitSet(a[1],!1);c=f.nextSetBit(0);if(0>c||c>=this.vwr.ms.ac||1!=f.cardinality())return!1;if(JS.SV.sValue(a[0]).equalsIgnoreCase("spaceGroup")){c=this.vwr.ms.generateCrystalClass(c,JU.P3.new3(NaN,NaN,NaN));b=Array(c.size());for(f=b.length;0<=--f;)b[f]=c.get(f);c=new JU.P3;2==a.length&&(e=0)}else c=this.vwr.ms.at[c]}if(null!=b)break;case 1:switch(a[0].tok){case 7:var h=a[0].getList(),b=Array(h.size());for(f=b.length;0<=--f;)b[f]=JS.SV.ptValue(h.get(f));break;
 case 10:f=JS.SV.getBitSet(a[0],!1);h=this.vwr.ms.getAtomPointVector(f);b=Array(h.size());for(f=b.length;0<=--f;)b[f]=h.get(f);break;default:return!1}break;default:return!1}b=this.vwr.getSymTemp().setPointGroup(null,c,b,null,!1,Float.isNaN(e)?this.vwr.getFloat(570425382):e,Float.isNaN(g)?this.vwr.getFloat(570425384):g,!0);return d.addXMap(b.getPointGroupInfo(-1,null,!0,null,0,1))},"JS.ScriptMathProcessor,~A");l(c$,"evaluateUnitCell",function(d,a,b){b=b?JS.SV.getBitSet(d.getX(),!0):null;b=(null==b?
-this.vwr.getAllAtoms():b).nextSetBit(0);var c=a.length-1,e=1;switch(0>c?0:a[c].tok){case 2:case 3:e=a[c].asFloat(),c--}var g=0>c?0:a[0].tok,f=null,h=null;switch(g){case 7:h=a[0].getList();break;case 4:var k=a[0].asString();if(0==k.indexOf("a=")){for(var f=Array(4),j=0;4>j;j++)f[j]=new JU.P3;JU.SimpleUnitCell.setOabc(k,null,f)}}k=null;j=null!=h;if(null==f&&j&&4>h.size())return!1;var m=j?1:0;null==f&&(!j&&8!=g)&&(k=0>b?null:this.vwr.ms.getUnitCell(this.vwr.ms.at[b].mi),f=null==k?y(-1,[JU.P3.new3(0,
-0,0),JU.P3.new3(1,0,0),JU.P3.new3(0,1,0),JU.P3.new3(0,0,1)]):k.getUnitCellVectors());if(null==f)if(f=Array(4),j)switch(h.size()){case 3:f[0]=new JU.P3;for(j=0;3>j;j++)f[j+1]=JU.P3.newP(JS.SV.ptValue(h.get(j)));break;case 4:for(j=0;4>j;j++)f[j]=JU.P3.newP(JS.SV.ptValue(h.get(j)));break;case 6:g=u(6,0);for(j=0;6>j;j++)g[j]=h.get(j).asFloat();JU.SimpleUnitCell.setOabc(null,g,f);break;default:return!1}else switch(f[0]=JS.SV.ptValue(a[0]),c){case 3:for(j=1;4>j;j++)(f[j]=JU.P3.newP(JS.SV.ptValue(a[j]))).sub(f[0]);
+this.vwr.getAllAtoms():b).nextSetBit(0);var c=a.length-1,e=1;switch(0>c?0:a[c].tok){case 2:case 3:e=a[c].asFloat(),c--}var g=0>c?0:a[0].tok,f=null,h=null;switch(g){case 7:h=a[0].getList();break;case 4:var k=a[0].asString();if(0==k.indexOf("a=")){for(var f=Array(4),j=0;4>j;j++)f[j]=new JU.P3;JU.SimpleUnitCell.setOabc(k,null,f)}else if(0<=k.indexOf(","))return d.addXObj(this.vwr.getV0abc(k))}k=null;j=null!=h;if(null==f&&j&&4>h.size())return!1;var m=j?1:0;null==f&&(!j&&8!=g)&&(k=0>b?null:this.vwr.ms.getUnitCell(this.vwr.ms.at[b].mi),
+f=null==k?y(-1,[JU.P3.new3(0,0,0),JU.P3.new3(1,0,0),JU.P3.new3(0,1,0),JU.P3.new3(0,0,1)]):k.getUnitCellVectors());if(null==f)if(f=Array(4),j)switch(h.size()){case 3:f[0]=new JU.P3;for(j=0;3>j;j++)f[j+1]=JU.P3.newP(JS.SV.ptValue(h.get(j)));break;case 4:for(j=0;4>j;j++)f[j]=JU.P3.newP(JS.SV.ptValue(h.get(j)));break;case 6:g=u(6,0);for(j=0;6>j;j++)g[j]=h.get(j).asFloat();JU.SimpleUnitCell.setOabc(null,g,f);break;default:return!1}else switch(f[0]=JS.SV.ptValue(a[0]),c){case 3:for(j=1;4>j;j++)(f[j]=JU.P3.newP(JS.SV.ptValue(a[j]))).sub(f[0]);
 break;case 1:if(h=a[1].getList(),null!=h&&3==h.size()){for(j=0;3>j;j++)f[j+1]=JS.SV.ptValue(h.get(j));break}default:return!1}j=m<=c?a[m].asString():null;if((h="primitive".equalsIgnoreCase(j))||"conventional".equalsIgnoreCase(j)){if(a=++m>c?"":a[m].asString().toUpperCase(),a.equals("BCC")?a="I":0==a.length&&(a=this.vwr.getSymTemp().getSymmetryInfoAtom(this.vwr.ms,b,null,0,null,null,null,1073741994,0,-1)),null==a||0==a.length||!(null==k?this.vwr.getSymTemp():k).toFromPrimitive(h,a.charAt(0),f))return!1}else"reciprocal".equalsIgnoreCase(j)&&
 (f=JU.SimpleUnitCell.getReciprocal(f,null,e),e=1);if(1!=e)for(j=1;4>j;j++)f[j].scale(e);return d.addXObj(f)},"JS.ScriptMathProcessor,~A,~B");l(c$,"evaluateArray",function(d,a,b){if(b){b=d.getX();switch(1==a.length?b.tok:0){case 6:var c=new JU.Lst,e=a[0].asString(),g=b.getMap(),f=b.getKeys(!1);b=0;for(a=f.length;b<a;b++)if(null==g.get(f[b]).getMap())return!1;b=0;for(a=f.length;b<a;b++){var h=g.get(f[b]),h=h.getMap(),h=JS.SV.deepCopy(h,!0,!1);h.put(e,JS.SV.newS(f[b]));c.addLast(JS.SV.newV(6,h))}return d.addXList(c);
 case 7:c=new java.util.Hashtable;e=b.getList();g=a[0].asString();b=0;for(a=e.size();b<a;b++)if(h=e.get(b).getMap(),null==h||null==h.get(g))return!1;b=0;for(a=e.size();b<a;b++)h=e.get(b),h=JS.SV.deepCopy(h.getMap(),!0,!1),f=h.remove(g),c.put(f.asString(),JS.SV.newV(6,h));return d.addXObj(c)}return!1}c=Array(a.length);for(b=c.length;0<=--b;)c[b]=JS.SV.newT(a[b]);return d.addXAV(c)},"JS.ScriptMathProcessor,~A,~B");l(c$,"evaluateBin",function(d,a){var b=a.length;if(3>b||5<b)return!1;var c=d.getX(),e=
