@@ -9,6 +9,7 @@
 * 
 */
 
+// BH 1/14/2017 7:12:47 PM adds proto._showTooltip
 // BH 4/24/2016 4:42:06 PM working around Resolver 2D issues
 // BH 2/2/2014 11:39:44 AM Jmol/JSME/JSV working triad
 // BH 1/30/2014 1:04:09 PM adds Info.viewSet 
@@ -204,7 +205,7 @@
 	}
 
 	proto._searchDatabase = function(query, database) {
-		return this._applet.runScript("load ID \"" + query + "\" " + database + query)
+		return this._applet.runScript("load ID \"" + query + "\" \"" + database + query + "\"")
 	}
 
 	proto._script = function(script) {
@@ -248,6 +249,26 @@
 		Jmol._loadFileData(this, fileName, function(data){me._loadInline(data)}, function(data){me._loadInline(null)});
 	}
 
+  proto._showTooltip = function(text) {
+    var s = "<span id='" + this._id + "_tooltip' style='position:absolute;z-index:10000000;left:0px;top:0px;background-color:yellow'></span>";
+    var t = this._tooltip;
+    if (!t) {    
+      Jmol.$after("body",s);
+      t = this._tooltip = Jmol.$(this, "tooltip");
+    }
+    t.hide();
+    this._tooltipTimer && clearTimeout(this._tooltipTimer);
+    this._tooltipTimer1 && clearTimeout(this._tooltipTimer1); 
+    var me = this;
+    this._tooltipTimer1 = setTimeout(function(){
+      t[0].style.left = (Jmol._mousePageX+10) + "px";
+      t[0].style.top = (Jmol._mousePageY+20) + "px";
+      t[0].innerHTML = text;
+      t.show();
+      me._tooltipTimer = setTimeout(function(){t.hide()},4000);
+    },50);
+  }
+  
 	proto._loadInline = function(data) {
 		// called when loading JDX data
 		this._currentView = null;
@@ -290,12 +311,12 @@
 			this._applet.runScriptNow("SELECT ID \"" + view.info.viewID + "\"");
 			return;
 		}
-		
 		// get the simulation into JSpecView
 		var script = this.__Info.preloadScript;
-		if (script == null) {
+		if (this._addC13)
+			script = "CLOSE ALL";
+		else if (script == null)
 			script = "CLOSE VIEWS;CLOSE SIMULATIONS > 1";
-    }
 		script += "; LOAD ID \"" + view.info.viewID + "\" APPEND \"http://SIMULATION/MOL=" + molData.replace(/\n/g,"\\n") + "\"";
   	if (this._addC13)
       script += "; LOAD ID \"" + view.info.viewID + "C13\" APPEND \"http://SIMULATION/C13/MOL=" + molData.replace(/\n/g,"\\n") + "\"";
@@ -324,6 +345,11 @@
 		this.__selectSpectrum();
 	}
 	
+  proto._reset = function(_jmol_resetView) {
+    this._script("view clear");
+  }
+  
+
 	proto._updateView = function(msgOrPanel, peakData, _jsv_updateView) {
 		if (this._viewSet == null || !this._applet || msgOrPanel && msgOrPanel.vwr)
 			return;
@@ -591,15 +617,17 @@
 	
 Jmol._newGrayScaleImage = function(context, image, width, height, grayBuffer) {
 	var c;
+  image || (image = Jmol.$(context.canvas.applet, "image")[0]);
 	if (image == null) {
-		var id = ("" + Math.random()).substring(3);
+		var appId = context.canvas.applet._id;
+    var id = appId + "_imagediv";
 		c = document.createElement("canvas");
 		c.id = id;
 		c.style.width = width + "px";
 		c.style.height = height + "px";
 		c.width = width;
 		c.height = height;
-		var appId = context.canvas.applet._id;
+
 		var layer = document.getElementById(appId + "_contentLayer");
 		image = new Image();
 		image.canvas = c;
@@ -615,7 +643,7 @@ Jmol._newGrayScaleImage = function(context, image, width, height, grayBuffer) {
 		};
 		var div = document.createElement("div");
 		image.div = div;
-		div.style.position="relative";
+		div.style.position="absolute";
 		layer.appendChild(div);
 		div.appendChild(image);
 	}
